SystemOrganization addCategory: #VolunteerMPlace!
SystemOrganization addCategory: #'VolunteerMPlace-Tests'!

TestCase subclass: #TestOffer
	instanceVariableNames: 'volun1 offer1 task1 task2 task3 skill1 skill2 skill3 coordinator project'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace-Tests'!

!TestOffer methodsFor: 'as yet unclassified' stamp: 'MGH 10/17/2012 17:14'!
setUp
	"set up test environment"
	
	CollectionSingleton reset.
	TaskCollection reset.
	CoordinatorCollection reset.
	ProjectCollection reset.
	SkillCollection reset.
	VolunteerCollection reset.

      coordinator := Coordinator new.
	coordinator name: 'Bruno' ;
				 email: 'collaco.bruno@gmail.com' ;
				 organization: 'IAG-USP'.
				
	project := ProjectX new.	
	project name: 'Weekend Classes' ;
		      description: 'This project aims to help students by giving extra classes on the weekends' ;
		      type: 'Extra Classes'. 
      project addCoordinator: coordinator.

	skill1 := Skill new.	
	skill1 name: 'Math Teacher' ;
		  description: 'to give classes of maths'. 
      skill1 save.
		
	skill2 := Skill new.	
	skill2 name: 'Phisics Teacher' ;
		  description: 'to give classes of phisics'.
      skill2 save.
		
	skill3 := Skill new.	
	skill3 name: 'Computation Teacher' ;
		  description: 'to give classes of computation'.
      skill3 save.
		
	volun1 := Volunteer new.
	volun1 createAccount: 'bruno' pass: 'bbc' name: 'Bruno'  email: 'collaco.bruno@gmail.com'                    photo: '' birthday: '1986-11-5'.
	volun1 save.
				
	offer1 := Offer new.	
			
	task1 := Task new.	
	task1 name: 'Give Math Classes' ;
		  description: 'to give classes at weekends...' ;
		  endDate: '2012-12-1' ;
              estimatedTime: 40. 
      task1 addSkill: skill1.
      task1 save.

	task2 := Task new.	
	task2 name: 'Give Phisics Classes' ;
		  description: 'to give classes at weekends...' ;
		  endDate: '2012-12-1' ;
              estimatedTime: 40. 
      task2 addSkill: skill2.
      task2 save.

	task3 := Task new.	
	task3 name: 'Give Computation Classes' ;
		  description: 'to give classes at weekends...' ;
		  endDate: '2012-12-1' ;
              estimatedTime: 40. 
      task3 addSkill: skill3.
      task3 save.

      project addTask: task1.
      project addTask: task2.
      project addTask: task3.
      project save.! !

!TestOffer methodsFor: 'as yet unclassified' stamp: 'MGH 10/22/2012 11:19'!
testChangeState
	"Coordinator changes the state of a task"

	coordinator ChangeState: task1 status: 'Running'.
	self assert: (task1 status = 'Running').
! !

!TestOffer methodsFor: 'as yet unclassified' stamp: 'MGH 10/17/2012 17:36'!
testCoordinatorResponse
	"coordinator responses the offer"
	|offer col|
	volun1 addSkill: skill1.
      volun1 addSkill: skill2.
      col:= volun1 suggestions.	
	volun1 SendOffer: (col at: 1) message: 'I want to do this task'.
      offer := (coordinator inbox) at: 1.
	coordinator ReviseOffer: offer message: 'Ok.' accepted: true.	
	self assert: ((task1 volunteers) size =1).
! !

!TestOffer methodsFor: 'as yet unclassified' stamp: 'MGH 10/22/2012 11:20'!
testCoordinatorSendOffer
	"coordinator sends an offer"
	|voluns Vol1|
      voluns := task1 getListOfVolunteers: ((VolunteerCollection default) collection).
      Vol1 := voluns at: 1.
      coordinator SendOffer: task1 message: 'Do you want to do this task?' volunteer: Vol1.
	self assert: ((Vol1 inbox) size =1).
! !

!TestOffer methodsFor: 'as yet unclassified' stamp: 'MGH 10/22/2012 11:22'!
testTaskSuggestions
	"coordinator views the volunteers that can do a task"
	|voluns|
      voluns := task1 getListOfVolunteers: ((VolunteerCollection default) collection).
	self assert: (voluns size =1).
! !

!TestOffer methodsFor: 'as yet unclassified' stamp: 'MGH 10/22/2012 11:22'!
testVolunteerOfferSomeTask
	"Volunteer views the tasks that can do, and send an offer"
	|col|
      volun1 addSkill: skill1.
      volun1 addSkill: skill2.
      col:= volun1 suggestions.	
	volun1 SendOffer: (col at: 1) message: 'I want to do this task'.
	self assert: ((coordinator inbox) size =1).
! !

!TestOffer methodsFor: 'as yet unclassified' stamp: 'MGH 10/22/2012 11:23'!
testVolunteerResponse
	"coordinator sends and offer and the volunteer responses the offer"
	|voluns Vol1 offer|
      voluns := task1 getListOfVolunteers: ((VolunteerCollection default) collection).
      Vol1 := voluns at: 1.
      coordinator SendOffer: task1 message: 'Do you want to do this task?' volunteer: Vol1.
      offer := (Vol1 inbox) at: 1.
      Vol1 responseOffer: 'Yes. I want' offer: offer accepted: true.
      Transcript cr; show: ((Vol1 inbox) size) printString.
	self assert: ((Vol1 inbox) size =0).
! !

!TestOffer methodsFor: 'as yet unclassified' stamp: 'MGH 10/17/2012 17:30'!
testVolunteerSkills
	"Volunteer adds skills"
      volun1 addSkill: skill1.
      volun1 addSkill: skill2.

 	self assert: ((volun1 skills) size =2).
! !

!TestOffer methodsFor: 'as yet unclassified' stamp: 'MGH 10/22/2012 11:25'!
testVolunteerSuggestion
	"Volunteer views the tasks that can do"
	|col|
      volun1 addSkill: skill1.
      volun1 addSkill: skill2.

      col:= volun1 suggestions.	
	self assert: (col size =2).
! !

TestCase subclass: #TestProject
	instanceVariableNames: 'aUser aCoordinator aProject aTask'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace-Tests'!

!TestProject methodsFor: 'running' stamp: 'BBC 10/22/2012 14:29'!
setUp
	"Creating variables for the tests"
	aUser := User new.
	aUser name: 'Mijail222' ;
	          login: 'exmija';
                password: '1234'.
	
	aCoordinator := Coordinator new.
	aCoordinator name: 'Renzo222';
	                     login: 'rgomez';
	                     password: '12345'.
	
	aProject := ProjectX new.	
	aProject name: 'Weekend Classes';
			  description: 'This project aims to help students by giving extra classes on the weekends' ;
		        type: 'Extra Classes'.
		
	aTask := Task new.	
	aTask name: 'Give Classes' ;
		  description: 'to give classes at weekends...' ;
		  endDate: '2012-12-1' ;
              estimatedTime: 40.  	
	
	"Reset database collections"
	VolunteerCollection reset.
	ProjectCollection reset.
	AdminCollection reset.
	TaskCollection reset.
	SkillCollection reset! !

!TestProject methodsFor: 'testing' stamp: 'RG 10/21/2012 15:18'!
testAddCoordinator
	"Testing that a coordinatoor of a project
	  can add other coordinators"
	| project |
	"Creating test project"
	project := ProjectX new.
	project name: 'Test Project 2'.
	"Setting aUser as creator (first coordinator) of project"
	project setCoordinator: aUser.
	project save.
	"Testing that aUser is a coordinator"
	self
		assert: (project isCoordinator: aUser).
	"Testing that aCoordinator isn't a coordinator of project"	
	self assert: (project isCoordinator: aCoordinator)
			= false.
	"Testing that aUser can add a coordinator to a project"
	(OperationValidator modifyProject: project user: aUser)
		ifTrue: [project addCoordinator: aCoordinator].
	"Testing that aCoordinator was addded to coordinator's list of project"	
	self
		assert: (project isCoordinator: aCoordinator)! !

!TestProject methodsFor: 'testing' stamp: 'RG 10/21/2012 15:29'!
testAddTask
	"Testing that a coodinator can add a task to his projects"
	| project aTask instance |
	"Creating a project"
	project := ProjectX new.
	project name: 'Test Project 3'.
	self assert: (project isCoordinator: aUser)
			= false.
	project setCoordinator: aUser.
	project save.
	"Testing that aUser is coordinator of project"
	self
		assert: (project isCoordinator: aUser).
	"Creating a task"	
	aTask := Task new.
	aTask name: 'Task 1'.
	aTask save.
	instance := TaskCollection default.
	"Testing that aTask was properly saved on database"
	self
		assert: (instance hasObject: aTask).
	"Testing that aUser can add a task to the project"	
	(OperationValidator modifyProject: project user: aUser)
		ifTrue: [project addTask: aTask].
	"Testing that aTask was added to project"	
	self
		assert: (project tasks includes: aTask)! !

!TestProject methodsFor: 'testing' stamp: 'RG 10/21/2012 15:37'!
testAddTaskFailure
	"Testing that user that isn't an admin or coordinator of a project can't add a task"
	| project aTask instance |
	"Creating project"
	project := ProjectX new.
	project name: 'Test Project 3'.
	"Testing that aUser isn't coordinator of project"
	self assert: (project isCoordinator: aUser)
			= false.
			
	project save.
	"Creating a task"
	aTask := Task new.
	aTask name: 'Task 1'.
	aTask save.
	instance := TaskCollection default.
	self
		assert: (instance hasObject: aTask).
	"Test if aUser can add a task"	
	(OperationValidator modifyProject: project user: aUser) ifTrue: 
		[project addTask: aTask.].
	"Test that aTask wasn't added"
	self
		assert: ((project tasks includes: aTask) = false)! !

!TestProject methodsFor: 'testing' stamp: 'RG 10/21/2012 15:44'!
testAdminAddTask
	"Testing that a coordinator can add tasks to his projects"
	| project aTask instance anAdmin |
	"Creating project"
	project := ProjectX new.
	project name: 'Test Project 3'.
	"Creating anAdmin from aUser (making aUser part of Admins)"
	anAdmin := Admin new.
	anAdmin setFromUser: aUser.
	anAdmin save.
	instance := AdminCollection default.
	"Testing that anAdmin was saved in database"
	self
		assert: (instance hasObject: anAdmin).
	project save.
	"Testing that aUser isn't coordinator of project"
	self assert: (project isCoordinator: aUser)
			= false.
	"Creating a task"		
	aTask := Task new.
	aTask name: 'Task 1'.
	aTask save.
	instance := TaskCollection default.
	"Testing that aTask was properly saved in Task's database"
	self
		assert: (instance hasObject: aTask).
	"Testing if aUser can add a task to project"	
	(OperationValidator modifyProject: project user: aUser)
		ifTrue: [project addTask: aTask].
	"Testing thar aTask was added to project"	
	self
		assert: (project tasks includes: aTask)! !

!TestProject methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:45'!
testCreatingProject
	"check if the project collection has a project recently added"

	| pc | 
	aProject save.
	pc := ProjectCollection default.
	
	self assert: (pc hasProject: aProject).

				
				
	! !

!TestProject methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:46'!
testIfProjectHasCoordinator
	"check if a project has a coordinator"

	aProject addCoordinator: aCoordinator.

	self assert: (aProject hasCoordinator: aCoordinator).

				
				
	! !

!TestProject methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:47'!
testIfProjectHasTask
	"tests adding a task to the project"

	| project task | 
	
	project:= ProjectX new.
	task := Task new.

	project addTask: task.

	self assert: (project hasTask: task).

				
				
	! !

!TestProject methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:48'!
testIfProjectHasVolunteer
	"tests adding a volunteer to the task and consequently to the project"

	| aVolunteer |
	
	aVolunteer := Volunteer new.
	aTask addVolunteer: aVolunteer.
	aProject addTask: aTask.

	self assert: (aProject hasVolunteer: aVolunteer).

				
				
	! !

!TestProject methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:48'!
testProjectAddComment
	"addind a comment to the project"

	| project comment result | 
	
	project := ProjectX new.
	comment := Comment new.
	
	comment message: 'This is a comment of the project'.
	result := project addComment: comment.
	project comments.

	self assert: (result).

				
				
	! !

!TestProject methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:52'!
testProjectEndDate
	"when a project finishes, its end date is set to current day."

	
	| project |

	project := ProjectX new.
	
	project status: 'Finished'.

	self assert: (project endDate = Date today).

				
				
	! !

!TestProject methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:52'!
testProjectRemoveComment
	"removing a comment"

	| aComment | 
	
	aComment := Comment new.
	aComment message: 'message bla !!'.
	aProject addComment: aComment.
	

	self assert: (aProject removeComment: aComment)

				
				
	! !

!TestProject methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:53'!
testProjectStatusChanges
	"if all project's tasks finishes, then the project also finishes."

	| p1 t1 shift result | 
	
	result := true.
	
	p1 := ProjectX new.
	t1 := Task new.
	
	(p1 status = 'Open') 
		ifTrue:  [shift := true]
		ifFalse: [shift := false. result := false.].
	
	p1 addTask: t1.
	
	t1 status: 'Finished'.
	
	(p1 status = 'Finished') 
		ifTrue:  [shift := true]
		ifFalse: [shift := false. result := false.].
	
	
	self assert: (result).

				
				
	! !

!TestProject methodsFor: 'testing' stamp: 'RG 10/21/2012 15:57'!
testProjectXCreation
	"Testing project creation"
	| project instanceProject instanceCoordinator |
	"Creating a project"
	project := ProjectX new.
	project name: 'Test project'.
	project setCoordinator: aUser.
	"Saving project to ProjectX's database"
	project save.
	instanceProject := ProjectCollection default.
	instanceCoordinator := CoordinatorCollection default.
	"Testing thar project was saved to database"
	self
		assert: (instanceProject hasObject: project).
	"Testing that project's creator is settled to it's first coordinator 
	  (Added to coordinator's database)"
	self
		assert: (instanceCoordinator hasObject: aUser)! !

!TestProject methodsFor: 'testing' stamp: 'RG 10/21/2012 15:48'!
testRemoveTaskAdmin
	"Testing that an Admin can remove a task from any project"
	| project aTask anAdmin |
	"Creating a project"
	project := ProjectX new.
	project name: 'Test Project 5'.
	project save.
	"Making aUser an Admin"
	anAdmin := Admin new.
	anAdmin setFromUser: aUser.
	anAdmin save.
	"Testing that aUser isn't a coordinator of project"
	self assert: (project isCoordinator: aUser)
			= false.
	"Creating a task"		
	aTask := Task new.
	aTask name: 'Task 3'.
	project addTask: aTask.
	"Testing if aUser can remove a task from project"
	(OperationValidator modifyProject: project user: aUser)
		ifTrue: [project removeTask: aTask].
	"Testing that aTask was removed"	
	self assert: (project tasks includes: aTask)
			= false! !

!TestProject methodsFor: 'testing' stamp: 'RG 10/21/2012 15:51'!
testRemoveTaskCoordinator
	"Testing that a coordinator can remove a task from his projects"
	| project aTask |
	"Creating project"
	project := ProjectX new.
	project name: 'Test Project 4'.
	project setCoordinator: aUser.
	project save.
	"Testing that aUser is coordinator of project"
	self
		assert: (project isCoordinator: aUser).
	"Creating a task"	
	aTask := Task new.
	aTask name: 'Task 2'.
	project addTask: aTask.
	"Test if aUser can remove a task from project"
	(OperationValidator modifyProject: project user: aUser)
		ifTrue: [project removeTask: aTask].
	"Testing thar aTask was removed from project"	
	self assert: (project tasks includes: aTask)
			= false! !

!TestProject methodsFor: 'testing' stamp: 'RG 10/21/2012 15:54'!
testRemoveTaskFailure
	"Test that a user that isn't a coordinator of a project or admin can't
	  remove a task"
	| project aTask |
	"Creating project"
	project := ProjectX new.
	project name: 'Test Project 5'.
	project save.
	"Testing that aUser isn't project's coordinator"
	self assert: (project isCoordinator: aUser)
			= false.
	"Creating a task"
	aTask := Task new.
	aTask name: 'Task 3'.
	project addTask: aTask.
	"Testing if aUser can remove a task from project"
	(OperationValidator modifyProject: project user: aUser)
		ifTrue: [project removeTask: aTask].
	"Testing that aTask wasn't removed"
	self
		assert: (project tasks includes: aTask)! !

TestCase subclass: #TestShowInfo
	instanceVariableNames: 'volun1 offer1 task1 task2 task3 skill1 skill2 skill3 coordinator project'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace-Tests'!

!TestShowInfo methodsFor: 'as yet unclassified' stamp: 'MGH 10/22/2012 13:28'!
ShowInfoProject: aProject
	"show information of the project"
	|size i tasks task templinha|
	tasks := aProject tasks.
      size := tasks size.
      i := 1.
      Transcript cr; show: 'name    status    depends on     Volunteers' printString.
      [[ i <= size ] whileTrue: 
        [ task:=tasks at: i.
          templinha := String new.
	    templinha := templinha, (task name) asString.
	    templinha := templinha,  Character tab asString,  Character tab asString.
	    templinha := templinha,  (task status) asString.
	    templinha := templinha,  Character tab asString.
	    templinha := templinha,  (task StrDepends) asString.
	    templinha := templinha,  Character tab asString.
	    templinha := templinha,  (task StrVolunteers) asString.
	    Transcript cr; show: templinha printString.
          i:=i+1.].]
      on: Exception
			do: [:ex | ^false. ].
	            ^true
	! !

!TestShowInfo methodsFor: 'as yet unclassified' stamp: 'MGH 10/22/2012 13:21'!
ShowTasksProject: aProject
	"show information of the project"
	|size i tasks task templinha|
	tasks := aProject tasks.
      size := tasks size.
      i := 1.
      Transcript cr; show: 'name    startDate    EstimatedTime' printString.
      [[ i <= size ] whileTrue: 
        [ task:=tasks at: i.
          templinha := String new.
	    templinha := templinha, (task name) asString.
	    templinha := templinha,  Character tab asString.
	    templinha := templinha, (task startDate) asString.
	    templinha := templinha, Character tab asString.
	    templinha := templinha, (task estimatedTime) asString.
	    Transcript cr; show: templinha printString.
          i:=i+1.].]
      on: Exception
			do: [:ex | ^false. ].
	            ^true! !

!TestShowInfo methodsFor: 'as yet unclassified' stamp: 'MGH 10/22/2012 13:30'!
setUp
	"set up test environment"
	
	CollectionSingleton reset.
	TaskCollection reset.
	CoordinatorCollection reset.
	ProjectCollection reset.
	SkillCollection reset.
	VolunteerCollection reset.

      coordinator := Coordinator new.
	coordinator name: 'Bruno' ;
				 email: 'collaco.bruno@gmail.com' ;
				 organization: 'IAG-USP'.
				
	project := ProjectX new.	
	project name: 'Weekend Classes' ;
		      description: 'This project aims to help students by giving extra classes on the weekends' ;
		      type: 'Extra Classes'. 
      project addCoordinator: coordinator.

	skill1 := Skill new.	
	skill1 name: 'Math Teacher' ;
		  description: 'to give classes of maths'. 
      skill1 save.
		
	skill2 := Skill new.	
	skill2 name: 'Phisics Teacher' ;
		  description: 'to give classes of phisics'.
      skill2 save.
		
	skill3 := Skill new.	
	skill3 name: 'Computation Teacher' ;
		  description: 'to give classes of computation'.
      skill3 save.
		
	volun1 := Volunteer new.
	volun1 createAccount: 'bruno' pass: 'bbc' name: 'Bruno'  email: 'collaco.bruno@gmail.com'                    photo: '' birthday: '1986-11-5'.
	volun1 save.
				
	offer1 := Offer new.	
			
	task1 := Task new.	
	task1 name: 'Give Math Classes' ;
		  description: 'to give classes at weekends...' ;
		  endDate: '2012-12-1' ;
              estimatedTime: 40. 
      task1 addSkill: skill1.
      task1 addVolunteer: volun1.
      task1 save.

	task2 := Task new.	
	task2 name: 'Give Phisics Classes' ;
		  description: 'to give classes at weekends...' ;
		  endDate: '2012-12-1' ;
              estimatedTime: 40. 
      task2 addSkill: skill2.
      task2 dependsOn: task1.
      task2 save.

	task3 := Task new.	
	task3 name: 'Give Computation Classes' ;
		  description: 'to give classes at weekends...' ;
		  endDate: '2012-12-1' ;
              estimatedTime: 40. 
      task3 addSkill: skill3.
      task3 save.

      project addTask: task1.
      project addTask: task2.
      project addTask: task3.
      project save.! !

!TestShowInfo methodsFor: 'as yet unclassified' stamp: 'MGH 10/22/2012 13:22'!
testShowInfoProject
	"show the tasks of a project, with the volunteers and dependences"

	self assert: (self ShowInfoProject: project).
! !

!TestShowInfo methodsFor: 'as yet unclassified' stamp: 'MGH 10/22/2012 13:22'!
testShowTasksProject
	"show the tasks of a project with the start date and the estimated time"

	self assert: (self ShowTasksProject: project).
! !

TestCase subclass: #TestSkill
	instanceVariableNames: 'aUser aSkill'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace-Tests'!

!TestSkill methodsFor: 'running' stamp: 'RG 10/21/2012 16:05'!
setUp
	"Reseting database collections"
	VolunteerCollection reset.
	ProjectCollection reset.
	AdminCollection reset.
	TaskCollection reset.
	SkillCollection reset.
	"Creating variables for the test"
	aUser := User new.
	aUser name: 'Mijail11'.
	aUser login: 'exmija'.
	aUser password: '1234'.
	
	aSkill := Skill new.
	aSkill name: 'Test Skill'.
	aSkill description: 'Test'! !

!TestSkill methodsFor: 'testing' stamp: 'RG 10/21/2012 16:04'!
testCreateSkill
	"Testing that an admin can add skills to the system"
	| instance |
	
	instance := SkillCollection default.
	"Testing that aUser can't add a skill to the system"
	self assert: (OperationValidator addSkill: aUser)
			= false.
			
	"Testing that skills database doesn'r contain aSkill"		
	self assert: (instance hasObject: aSkill)
			= false.
	
	"Adding aUser to Admin's database"
	instance := AdminCollection default.
	instance addAdmin: aUser.
	"Testing that aUser now can add a skill to the system"
	(OperationValidator addSkill: aUser) ifTrue: 
		[aSkill save.].
	"Testing that aSkill was saved in database"
	instance := SkillCollection default.
	self
		assert: (instance hasObject: aSkill)! !

TestCase subclass: #TestTask
	instanceVariableNames: 'aProject aCoordinator aTask'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace-Tests'!

!TestTask methodsFor: 'running' stamp: 'RG 10/21/2012 15:11'!
setUp
	"Reset the database collections"
	ProjectCollection reset.
	TaskCollection reset.
	AdminCollection reset.
	CoordinatorCollection reset.
	SkillCollection reset.
	"Creating a coordinator for aProject"
	aCoordinator := Coordinator new.
	aCoordinator name: 'Test Coordinator'.
	"Creating aProject"
	aProject := ProjectX new.
	aProject name: 'Test Project 5'.
	"Creating a task for aProject"
	aTask := Task new.
	aTask name: 'Test Task'.
	
	aProject addCoordinator: aCoordinator.
	aProject addTask: aTask! !

!TestTask methodsFor: 'testing' stamp: 'RG 10/21/2012 14:49'!
testAddSkillCoordinator
	"Testing the addition of a skill to a task"
	| aSkill |
	aSkill := Skill new.
	aSkill name: 'PHP Programming'.
	aSkill description: 'Knows to program in PHP'.
	"Testing if aTask is part of aProject (both variables were created in setUp method)"
	self
		assert: (aProject tasks includes: aTask).
	"Testing that aSkill isn't part of the aTask skills "	
	self assert: ((aTask hasSkill: aSkill) = false).
	"Testing the aCoordinator can add skill to a project's tasks"		
	(OperationValidator modifyProject: aProject user: aCoordinator)
		ifTrue: [aTask addSkill: aSkill].
	"Testing that aSkill was properly added"	
	self
		assert: (aTask hasSkill: aSkill)! !

!TestTask methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:55'!
testCreatingTask
	"check if the task collection has a task recently added"

	| tc | 
	aTask save.
	tc := TaskCollection default.
	
	self assert: (tc hasTask: aTask).

				
				
	! !

!TestTask methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:55'!
testIfTaskEstimatedTime
	"adding the estimeated time (hours) of a task as an integer"

	aTask estimatedTime: 100.

	self assert: (aTask estimatedTime = 100).

				
				
	! !

!TestTask methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:56'!
testIfTaskHasSkill
	"check if a task has a skill recently added"

	| aSkill | 
	aSkill := Skill new.
	aSkill name: 'Skill_1'.
	aTask addSkill: aSkill.

	self assert: (aTask hasSkill: aSkill).

				
				
	! !

!TestTask methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:56'!
testIfTaskHasVolunteer
	"check if a task has a volunteer recently added"

	| aVolunteer | 
	aVolunteer := Volunteer new.
	aVolunteer name: 'Volunteer_1'.
	aTask addVolunteer: aVolunteer.

	self assert: (aTask hasVolunteer: aVolunteer).

				
				
	! !

!TestTask methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:57'!
testIfTaskIsFromAnyProject
	"check from which project a task is"

	aProject addTask: aTask.

	self deny: (aTask fromProject = nil).

				
				
	! !

!TestTask methodsFor: 'testing' stamp: 'RG 10/21/2012 14:55'!
testRemoveSkillAdmin
	"Testing that an Admin can remove a skill"
	| aSkill anAdmin |
	aSkill := Skill new.
	aSkill name: 'PHP Programming'.
	aSkill description: 'Knows to program in PHP'.
	aTask addSkill: aSkill.
	"Testing that aSkill was properly added"
	self
		assert: (aTask hasSkill: aSkill).
	"Creating an Admin"	
	anAdmin := Admin new.
	anAdmin name: 'Test Admin'.
	anAdmin save.
	"Testing if an Admin can remove a skill"
	(OperationValidator modifyProject: aProject user: anAdmin)
		ifTrue: [aTask removeSkill: aSkill].
	"Testing that aSkill was removed"
	self assert: ((aTask hasSkill: aSkill) = false).
	
	AdminCollection reset! !

!TestTask methodsFor: 'testing' stamp: 'RG 10/21/2012 15:06'!
testRemoveSkillCoordinator
	"Testing that the coordinator of a project can remove a skill of a task "
	| aSkill |
	aSkill := Skill new.
	aSkill name: 'PHP Programming'.
	aSkill description: 'Knows to program in PHP'.
	aTask addSkill: aSkill.
	"Testing that aSkill was properly added"
	self
		assert: (aTask hasSkill: aSkill).
	"Testing that aCoordinator can remove a skill from a task"	
	(OperationValidator modifyProject: aProject user: aCoordinator)
		ifTrue: [aTask removeSkill: aSkill].
	"Testing that aSkill was removed"	
	self assert: ((aTask hasSkill: aSkill) = false)! !

!TestTask methodsFor: 'testing' stamp: 'RG 10/21/2012 15:10'!
testRemoveSkillFailure
	"Testing that a user that isn't an admin or a coordinator of the project 
	  can't remove a skill from a task"
	| aSkill aUser |
	aSkill := Skill new.
	aSkill name: 'PHP Programming'.
	aSkill description: 'Knows to program in PHP'.
	aTask addSkill: aSkill.
	"Testing that aSkill was properly added to aTask"
	self
		assert: (aTask hasSkill: aSkill).
	"Creating a dummy user"
	aUser := User new.
	aUser name: 'Test User'.
	"Testing if aUser can remove a skill"
	(OperationValidator modifyProject: aProject user: aUser)
		ifTrue: [aTask removeSkill: aSkill].
	"Testing that aSkill wasn't removed"
	self
		assert: (aTask hasSkill: aSkill)! !

!TestTask methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:57'!
testTaskAddComment
	"adding a comment to the task"

	| aComment result |
	
	aComment := Comment new.
	aComment message: 'This is a comment of the task'.
	result := aTask addComment: aComment.
	aTask comments.
	

	self assert: (result)

				
				
	! !

!TestTask methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:58'!
testTaskBecomeFrozen
	"if a task has any dependences that are open, then the task becomes frozen, waiting for its dependences to finish"

	| firstTask|
	
	firstTask := Task new.
	firstTask name: 'Needed Task'.
	
	aTask dependsOn: firstTask.
	
	self assert: ((aTask status) = 'Frozen').

				
				
	! !

!TestTask methodsFor: 'creating' stamp: 'BBC 10/22/2012 14:59'!
testTaskDependences
	"if all task dependences changes their status to finished, then the dependent task becomes opened."

	| firstTask secondTask shift |
	
	shift := false.
	
	firstTask := Task new.
	firstTask name: 'First Task'.
	
	secondTask := Task new.
	secondTask name: 'Second Task'.
	
	firstTask dependsOn: secondTask.
	((firstTask status) = 'Frozen') ifTrue: [shift := true]. 
	
	secondTask status: 'Finished'.
	((firstTask status) = 'Open') ifFalse: [shift := false]. 
	
	
	
	self assert: (shift)

				
				
	! !

!TestTask methodsFor: 'creating' stamp: 'BBC 10/22/2012 15:00'!
testTaskEndDate
	"if a task's status is set to finished, then its end date becomes the current day."

	| t1 |
	
	t1 := Task new.


	t1 status: 'Finished'.

	self assert: (t1 endDate = Date today).

				
				
	! !

!TestTask methodsFor: 'creating' stamp: 'BBC 10/22/2012 15:00'!
testTaskRemoveComment
	"removing a comment from a task"

	| aComment | 
	
	aComment := Comment new.
	aComment message: 'message bla !!'.
	aTask addComment: aComment.
	

	self assert: (aTask removeComment: aComment)

				
				
	! !

!TestTask methodsFor: 'creating' stamp: 'BBC 10/22/2012 15:01'!
testTaskStartDate
	"when a task is created, its start date is set to the curent day"


	self assert: (aTask startDate = Date today).

				
				
	! !

TestCase subclass: #TestUser
	instanceVariableNames: 'project user aCoordinator'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace-Tests'!

!TestUser methodsFor: 'running' stamp: 'BBC 10/22/2012 14:41'!
setUp
	"Reset the database collections"
	VolunteerCollection reset.
	ProjectCollection reset.
	AdminCollection reset.
	TaskCollection reset.
	SkillCollection reset.
	Comment reset.
	"Creating the project that will include the comment"
	project := ProjectX new.
	project name: 'Test Project 4'.
	project save.
	"Setting the user of the comment"
	user := User new.
	user name: 'Renzo333'.
	user login: 'rgomez'.
	user password: '1234'.
	"Creating a coordinator"
	aCoordinator := Coordinator new.
	aCoordinator name: 'Renzo222';
	                     login: 'rgomez';
	                     password: '12345'.
	

! !

!TestUser methodsFor: 'testing' stamp: 'RG 10/21/2012 14:21'!
testAddComment
	"Test the addition of a comment to a project"
	| aComment |
	aComment := Comment new.
	aComment user: user.
	"user and project where created in the setUp method"
	project addComment: aComment.
	self
		assert: (project comments includes: aComment)! !

!TestUser methodsFor: 'testing' stamp: 'RG 10/21/2012 14:21'!
testCreateUser
	"Test User creation"
	| aUser volunteer instance |
	aUser := User new.
	aUser name: 'Foo'.
	aUser login: 'bar'.
	aUser password: '1234'.
	volunteer := Volunteer new.
	volunteer setFromUser: aUser.
	volunteer save.
	instance := VolunteerCollection default.
	self
		assert: (instance hasObject: volunteer)! !

!TestUser methodsFor: 'creating' stamp: 'BBC 10/22/2012 15:02'!
testCreatingCoordinator
	"check if the coordinator collection has a coordinator recently added."

	| cc | 
	aCoordinator save.
	cc := CoordinatorCollection default.
	
	self assert: (cc hasCoordinator: aCoordinator).

				
				
	! !

!TestUser methodsFor: 'testing' stamp: 'RG 10/21/2012 14:24'!
testRemoveCommentAdmin
	"Test that an Admin can remove any comment"
	| anAdmin aComment |
	anAdmin := Admin new.
	anAdmin name: 'Test'.
	anAdmin login: 'test'.
	anAdmin password: '12345'.
	anAdmin save.
	aComment := Comment new.
	aComment user: user.
	project addComment: aComment.
	"Test that the comment was added successfully"
	self
		assert: (project comments includes: aComment).
	"Testing if the Admin can modify anything in the project"
	(OperationValidator
			modifyComment: aComment
			project: project
			user: anAdmin)
		ifTrue: [project removeComment: aComment].
	"Testing if comment was deleted"	
	self assert: ((project comments includes: aComment) = false)! !

!TestUser methodsFor: 'testing' stamp: 'RG 10/21/2012 14:27'!
testRemoveCommentCoordinator
	"Test that a coordinator of a project
	  can remove a comment from that project"
	| aCoordinator aComment |
	aCoordinator := Coordinator new.
	aCoordinator name: 'Brunp'.
	aCoordinator login: 'bruno'.
	aCoordinator password: '12345'.
	project addCoordinator: aCoordinator.
	aComment := Comment new.
	aComment user: user.
	project addComment: aComment.
	"Testing that comment was properly added"
	self
		assert: (project comments includes: aComment).
	"Testing if aCoordinator can remove that comment"
	(OperationValidator
			modifyComment: aComment
			project: project
			user: aCoordinator)
		ifTrue: [project removeComment: aComment].
	"Testing that comment was removed"	
	self assert: ((project comments includes: aComment) = false)! !

!TestUser methodsFor: 'testing' stamp: 'RG 10/21/2012 14:32'!
testRemoveCommentFailure
	"Testing thar a user that is not a coordinator, admin or creator
	  can't remove a comment from a project"
	| aUser aComment |
	aUser := User new.
	aUser name: 'Mijail'.
	aUser login: 'mija'.
	aUser password: '12345'.
	aComment := Comment new.
	"variable user was created in the setUp method"
	aComment user: user.
	project addComment: aComment.
	"Testing that aComment was added properly to the project"
	self
		assert: (project comments includes: aComment).
	"Testing if aUser can remove aComment"	
	(OperationValidator
			modifyComment: aComment
			project: project
			user: aUser)
		ifTrue: [project removeComment: aComment.].
	"Testing that aComment wasn't removed"	
	self
		assert: (project comments includes: aComment)! !

!TestUser methodsFor: 'testing' stamp: 'RG 10/21/2012 14:35'!
testRemoveCommentUser
	"Testing that the creator of the comment can remove it"
	| aComment |
	aComment := Comment new.
	aComment user: user.
	project addComment: aComment.
	"Testing that aComment was properly added to the project"
	self
		assert: (project comments includes: aComment).
	"Testing the user can remove the comment"	
	(OperationValidator
			modifyComment: aComment
			project: project
			user: user)
		ifTrue: [project removeComment: aComment].
	"Testing if the comment was removed"	
	self assert: ((project comments includes: aComment)= false)! !

Object subclass: #CollectionSingleton
	instanceVariableNames: 'list'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

CollectionSingleton class
	instanceVariableNames: 'soleInstance'!

!CollectionSingleton commentStamp: 'RG 10/6/2012 15:04' prior: 0!
Singleton of a collection of objects!

CollectionSingleton class
	instanceVariableNames: 'soleInstance'!

CollectionSingleton subclass: #AdminCollection
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!AdminCollection methodsFor: 'as yet unclassified' stamp: 'RG 10/12/2012 20:51'!
addAdmin: anAdmin	
	| result |
	result := (super add: anAdmin).
	(result) ifTrue: [ Transcript cr ; show: (anAdmin name), ' added as Admin'. ].! !

!AdminCollection methodsFor: 'as yet unclassified' stamp: 'RG 10/12/2012 20:53'!
removeAdmin: anAdmin
	"removes an admin from the collection"
	| result |
	result := super remove: anAdmin.
	(result) ifTrue: [ Transcript cr ; show: (anAdmin name), ' removed from Admins'. ].! !

!CollectionSingleton class methodsFor: 'instance edition' stamp: 'RG 10/6/2012 15:07'!
default
	"Get the unique instance"

	(soleInstance isNil) ifTrue: [soleInstance := self basicNew initialize].
	^ soleInstance! !

!CollectionSingleton class methodsFor: 'instance creation' stamp: 'RG 10/6/2012 15:06'!
new
	"comment stating purpose of message"

	self error: 'Cannot create a new instance.'! !

!CollectionSingleton class methodsFor: 'instance edition' stamp: 'BBC 10/13/2012 18:28'!
reset
	"Reset the unique instance to nil"

	soleInstance := nil.
	"Transcript cr; show: 'This collection has been reseted.'"! !

!CollectionSingleton methodsFor: 'editing' stamp: 'BBC 10/13/2012 13:06'!
add: anObject
	"Adds an element to the collection
	 returns true or false depending on the outcome of the operation."
	
	
	
	(self hasObject: anObject)
		ifTrue: [[Transcript cr; show: 'You can not save it twice, please use update instead!!'] 
				on: Exception
				do: [:ex | ^true. ].
	            	^false.]
		ifFalse: [
			[ list add: anObject. ]
			on: Exception
			do: [:ex | ^false. ].
			Smalltalk snapshot: true andQuit: false.
	            ^true.]

	
	"[ list add: anObject. ]
	on: Exception
	do: [:ex | ^false. ].
	^true."! !

!CollectionSingleton methodsFor: 'gets' stamp: 'RG 10/6/2012 16:08'!
collection
	"Return the collection of objects in the system"
	^list.! !

!CollectionSingleton methodsFor: 'as yet unclassified' stamp: 'RG 10/12/2012 20:25'!
getObject: anObject
	| index |
	index := list indexOf: anObject ifAbsent: [ 0. ].
	(index > 0) ifTrue: [ ^list at: index. ].
	^nil.! !

!CollectionSingleton methodsFor: 'gets' stamp: 'RG 10/12/2012 19:45'!
hasObject: anObject
	"Returns if an object is in the collection"
	| index |
	index := list indexOf: anObject ifAbsent: [ 0 ].
	^ ( index > 0 ).
	! !

!CollectionSingleton methodsFor: 'initialize-release' stamp: 'RG 10/6/2012 15:11'!
initialize
	"Initialize the list of objects"
	list := OrderedCollection new.! !

!CollectionSingleton methodsFor: 'editing' stamp: 'RG 10/6/2012 15:15'!
remove: anObject
	"remove a collection from the list
	 returns true or false depending on the outcome of the operation."
	| index |
	[index := (list find: anObject).
	(index isNil) ifFalse: [list removeAt: index]. ]
	on: Exception
	do: [:ex | ^false. ].
	^true.! !

!CollectionSingleton methodsFor: 'editing' stamp: 'RG 10/6/2012 15:19'!
update: anObject
	"Updates an element of the collection
	 returns true or false depending on the outcome of the operation."
	| result |
	result := self remove: anObject.
	(result) ifTrue: [
		result := self add: anObject.	
	].
	^result.! !

CollectionSingleton subclass: #CoordinatorCollection
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!CoordinatorCollection methodsFor: 'editing' stamp: 'BBC 10/8/2012 15:57'!
addCoordinator: aCoordinator
	"Adds a coordinator in the collection"
	
	| result |
	
	result := (super add: aCoordinator).
	(result) ifTrue: [ Transcript cr ; show: (aCoordinator name), ' added as Coordinator'. ].! !

!CoordinatorCollection methodsFor: 'checking' stamp: 'BBC 10/13/2012 13:20'!
hasCoordinator: aCoordinator
	"Test if contains a coordinator"

	^(super collection includes: aCoordinator) ! !

!CoordinatorCollection methodsFor: 'editing' stamp: 'BBC 10/8/2012 15:57'!
removeCoordinator: aCoordinator
	"removes a coordinator from the collection"
	
	| result |
	
	result := super remove: aCoordinator.
	(result) ifTrue: [ Transcript cr ; show: (aCoordinator name), ' removed from Coordinators'. ].! !

!CoordinatorCollection methodsFor: 'editing' stamp: 'BBC 10/8/2012 15:38'!
updateCoordinator: aCoordinator
	"Updates a coordinator from the collection"
	
	| result |
	
	result := super update: aCoordinator.
	( result ) ifTrue: [ Transcript cr ; show: (aCoordinator name), ' updated'.  ]! !

CollectionSingleton subclass: #OfferCollection
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!OfferCollection methodsFor: 'editing' stamp: 'MGH 10/14/2012 21:48'!
addOffer: aOffer
	"Adds an offer in the collection"
	
	| result |
	
	result := (super add: aOffer).
	(result) ifTrue: [ Transcript cr ; show: (aOffer name), ' added in Projects'. ].! !

!OfferCollection methodsFor: 'checking' stamp: 'MGH 10/14/2012 21:49'!
hasOffer: aOffer
	"Test if contains a offer"

	^(super collection includes: aOffer) ! !

!OfferCollection methodsFor: 'editing' stamp: 'MGH 10/14/2012 21:49'!
removeOffer: aOffer
	"removes a offer from the collection"
	
	| result |
	
	result := super remove: aOffer.
	(result) ifTrue: [ Transcript cr ; show: (aOffer name), ' removed from Projects'. ].! !

!OfferCollection methodsFor: 'editing' stamp: 'MGH 10/14/2012 21:50'!
updateOffer: aOffer
	"Updates a offer from the collection"
	
	| result |
	
	result := super update: aOffer.
	( result ) ifTrue: [ Transcript cr ; show: (aOffer name), ' updated'.  ]! !

CollectionSingleton subclass: #ProjectCollection
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!ProjectCollection methodsFor: 'editing' stamp: 'BBC 10/8/2012 16:01'!
addProject: aProject
	"Adds a project in the collection"
	
	| result |
	
	result := (super add: aProject).
	(result) ifTrue: [ Transcript cr ; show: (aProject name), ' added in Projects'. ].! !

!ProjectCollection methodsFor: 'checking' stamp: 'BBC 10/13/2012 13:57'!
hasProject: aProject
	"Test if contains a project"

	^(super collection includes: aProject) ! !

!ProjectCollection methodsFor: 'editing' stamp: 'BBC 10/8/2012 16:02'!
removeProject: aProject
	"removes a project from the collection"
	
	| result |
	
	result := super remove: aProject.
	(result) ifTrue: [ Transcript cr ; show: (aProject name), ' removed from Projects'. ].! !

!ProjectCollection methodsFor: 'editing' stamp: 'BBC 10/8/2012 16:04'!
updateProject: aProject
	"Updates a project from the collection"
	
	| result |
	
	result := super update: aProject.
	( result ) ifTrue: [ Transcript cr ; show: (aProject name), ' updated'.  ]! !

CollectionSingleton subclass: #SkillCollection
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!SkillCollection commentStamp: 'RG 10/6/2012 15:21' prior: 0!
Collection of Skills of the system!

!SkillCollection methodsFor: 'editing' stamp: 'BBC 10/8/2012 14:38'!
addSkill: aSkill
	"Add a skill in the collection"
	| result |
	result := (super add: aSkill).
	(result) ifTrue: [ Transcript cr ; show: (aSkill name), ' added in Skills'. ].! !

!SkillCollection methodsFor: 'checking' stamp: 'BBC 10/13/2012 13:58'!
hasSkill: aSkill
	"Test if contains a skill"

	^(super collection includes: aSkill) ! !

!SkillCollection methodsFor: 'editing' stamp: 'RG 10/6/2012 15:28'!
removeSkill: aSkill
	"removes a skill from the collection"
	| result |
	result := super remove: aSkill.
	(result) ifTrue: [ Transcript cr ; show: (aSkill name), ' removed from Skills'. ].

	! !

!SkillCollection methodsFor: 'editing' stamp: 'RG 10/6/2012 15:30'!
updateSkill: aSkill
	"Updates a skill from the collection"
	| result |
	result := super update: aSkill.
	( result ) ifTrue: [ Transcript cr ; show: (aSkill name), ' updated'.  ]! !

CollectionSingleton subclass: #TaskCollection
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!TaskCollection methodsFor: 'editing' stamp: 'BBC 10/13/2012 13:10'!
addTask: aTask
	"Add a task in the collection"
	| result |
	result := (super add: aTask).
	(result) ifTrue: [Transcript cr ; show: (aTask name), ' added in Tasks']! !

!TaskCollection methodsFor: 'checking' stamp: 'BBC 10/13/2012 13:59'!
hasTask: aTask
	"Test if contains a task"

	^(super collection includes: aTask) ! !

!TaskCollection methodsFor: 'editing' stamp: 'BBC 10/8/2012 14:38'!
removeTask: aTask
	"removes a task from the collection"
	| result |
	result := super remove: aTask.
	(result) ifTrue: [ Transcript cr ; show: (aTask name), ' removed from Tasks'. ].! !

!TaskCollection methodsFor: 'editing' stamp: 'BBC 10/8/2012 16:30'!
updateTask: aTask
	"Updates a task from the collection"
	
	| result |
	
	result := super update: aTask.
	( result ) ifTrue: [ Transcript cr ; show: (aTask name), ' updated'.  ]! !

CollectionSingleton subclass: #VolunteerCollection
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!VolunteerCollection commentStamp: 'RG 10/6/2012 15:44' prior: 0!
A collection of volunteers of the system.!

!VolunteerCollection methodsFor: 'editing' stamp: 'BBC 10/8/2012 15:58'!
addVolunteer: aVolunteer
	"Add a volunteer in the collection"
	| result |
	result := (super add: aVolunteer).
	(result) ifTrue: [ Transcript cr ; show: (aVolunteer name), ' added as Volunteer'. ].! !

!VolunteerCollection methodsFor: 'checking' stamp: 'BBC 10/13/2012 14:00'!
hasVolunteer: aVolunteer
	"Test if contains a volunteer"

	^(super collection includes: aVolunteer) ! !

!VolunteerCollection methodsFor: 'editing' stamp: 'RG 10/6/2012 15:46'!
removeVolunteer: aVolunteer
	"removes a volunteer from the collection"
	| result |
	result := super remove: aVolunteer.
	(result) ifTrue: [ Transcript cr ; show: (aVolunteer name), ' removed from Volunteers'. ].! !

!VolunteerCollection methodsFor: 'editing' stamp: 'RG 10/6/2012 15:48'!
updateVolunteer: aVolunteer
	"Updates a skill from the collection"
	| result |
	result := super update: aVolunteer.
	( result ) ifTrue: [ Transcript cr ; show: (aVolunteer name), ' updated'.  ]! !

Object subclass: #Comment
	instanceVariableNames: 'id user message date'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

Comment class
	instanceVariableNames: 'counter'!

!Comment commentStamp: 'RG 10/8/2012 15:04' prior: 0!
Represents a user commentary!

Comment class
	instanceVariableNames: 'counter'!

!Comment class methodsFor: 'as yet unclassified' stamp: 'RG 10/14/2012 11:45'!
counter
	| temp |
	(counter isNil) ifTrue: [ counter := 1. ].
	temp := counter.
	counter := counter + 1.
	^temp.! !

!Comment class methodsFor: 'as yet unclassified' stamp: 'RG 10/14/2012 13:35'!
reset
	"Resets counter of instances"
	counter := 1.! !

!Comment methodsFor: 'comparing' stamp: 'RG 10/14/2012 11:47'!
= aComment
	^ (id = aComment id)! !

!Comment methodsFor: 'gets' stamp: 'RG 10/8/2012 15:09'!
date
	"gets the date of creation of the comment"
	^date.! !

!Comment methodsFor: 'sets' stamp: 'RG 10/8/2012 15:09'!
date: aDate
	"sets the date of the comment"
	date := aDate.! !

!Comment methodsFor: 'gets' stamp: 'RG 10/14/2012 11:47'!
id
	^id.! !

!Comment methodsFor: 'initialize-release' stamp: 'RG 10/14/2012 11:43'!
initialize
	"Empty constructor"
	id := Comment counter.
	date := nil.
	user := nil.
	message := ''.! !

!Comment methodsFor: 'gets' stamp: 'RG 10/8/2012 15:07'!
message
	"gets the message of the comentary"
	^message! !

!Comment methodsFor: 'sets' stamp: 'RG 10/8/2012 15:08'!
message: aMessage
	"sets the message of the comment"
	message := aMessage.! !

!Comment methodsFor: 'gets' stamp: 'RG 10/8/2012 15:05'!
user
	"gets the user"
	^user! !

!Comment methodsFor: 'sets' stamp: 'RG 10/8/2012 15:06'!
user: aUser
	"sets a user"
	user := aUser! !

Object subclass: #LoginVerifier
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!LoginVerifier commentStamp: 'RG 10/8/2012 14:29' prior: 0!
Class that verifies the user login!

!LoginVerifier class methodsFor: 'operations' stamp: 'RG 10/8/2012 15:50'!
search: aListOfUsers login: aLogin password: aPassword
	"comment stating purpose of message"
	aListOfUsers do: [ :each |
			((each login = aLogin) and: (each password = aPassword))  ifTrue: [ ^each. ].
		].
	^nil.! !

!LoginVerifier class methodsFor: 'operations' stamp: 'RG 10/8/2012 15:42'!
verify: aLogin password: aPassword
	"Returns the user associated with the Login and Password"
	| instance list result |
	instance := VolunteerCollection default.
	list := instance collection.
	result := self search: list.
	( result isNil ) ifFalse: [ ^result. ]. 
	^nil.
	! !

Object subclass: #Offer
	instanceVariableNames: 'sender task receiver message response accepted sentDate responseDate'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!Offer commentStamp: 'MGH 10/8/2012 16:01' prior: 0!
This class represents an offer.!

!Offer methodsFor: 'as yet unclassified' stamp: 'MGH 10/14/2012 21:46'!
= aOffer
	"Testing Equality"
	
	^ (((self sender) = (aOffer sender))&((self task) = (aOffer task))).! !

!Offer methodsFor: 'as yet unclassified' stamp: 'MGH 10/17/2012 17:28'!
ResponseOffer: aAccepted message: aMessage
	"Send a offer to some user"
	response := aMessage.
	accepted := aAccepted.
	sender addOffer: aMessage offer: self.
	responseDate := DateAndTime now.! !

!Offer methodsFor: 'as yet unclassified' stamp: 'MGH 10/17/2012 16:53'!
SendOffer: aSender receiver: aReceiver message: aMessage task: aTask
	"Send a offer to some user"
	sender := aSender.
	task := aTask.
	receiver := aReceiver.
	message := aMessage.
	receiver addOffer: aMessage offer: self.
	sentDate := DateAndTime now.! !

!Offer methodsFor: 'as yet unclassified' stamp: 'MGH 10/17/2012 17:19'!
SendOffer: aSender task: aTask message: aMessage
	"Send a offer to some user"
	|coordinators size i coordinator|
	sender := aSender.
	task := aTask.
	coordinators := (task fromProject) coordinators.
	receiver := coordinators at: 1.
	message := aMessage.
	sentDate := DateAndTime now.
	size := coordinators size.
      i := 1.
      [ i <= size ] whileTrue: 
        [ coordinator:=coordinators at: i.
          coordinator addOffer: aMessage offer: self.
          i:=i+1.].

	! !

!Offer methodsFor: 'as yet unclassified' stamp: 'MGH 10/14/2012 23:39'!
receiver
	"Answer the value of task"

	^ receiver! !

!Offer methodsFor: 'as yet unclassified' stamp: 'MGH 10/14/2012 23:39'!
receiver: aReceiver
	"comment stating purpose of message"
	receiver := aReceiver.! !

!Offer methodsFor: 'persistence' stamp: 'MGH 10/14/2012 21:53'!
remove
	"remove the offer from the system"
	
	| instance |
	
	instance := OfferCollection default.
	instance removeOffer: self.
	Smalltalk snapshot: true andQuit: false.	 ! !

!Offer methodsFor: 'persistence' stamp: 'MGH 10/14/2012 21:54'!
save
	"saves the offer in the system"
	
	| offerInstance |
	
	offerInstance := OfferCollection default.
	offerInstance addOffer: self.
	"Smalltalk snapshot: true andQuit: false".	! !

!Offer methodsFor: 'as yet unclassified' stamp: 'MGH 10/17/2012 17:37'!
sender
	"Answer the value of task"

	^ sender! !

!Offer methodsFor: 'as yet unclassified' stamp: 'MGH 10/17/2012 17:37'!
sender: aSender
	"comment stating purpose of message"
	sender := aSender.! !

!Offer methodsFor: 'as yet unclassified' stamp: 'MGH 10/14/2012 23:26'!
task
	"Answer the value of task"

	^ task! !

!Offer methodsFor: 'as yet unclassified' stamp: 'MGH 10/14/2012 23:26'!
task: aTask
	"comment stating purpose of message"
	task := aTask.! !

!Offer methodsFor: 'persistence' stamp: 'MGH 10/14/2012 21:55'!
update
	"updates the information of the offer from the system"
	| instance |
	instance := OfferCollection default.
	instance updateOffer: self.
	Smalltalk snapshot: true andQuit: false.	 ! !

Object subclass: #OperationValidator
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!OperationValidator class methodsFor: 'as yet unclassified' stamp: 'RG 10/14/2012 11:30'!
addSkill: aUser
	"return true if the user can add a skill,
	 false otherwise"
	^ self isAdmin: aUser.! !

!OperationValidator class methodsFor: 'as yet unclassified' stamp: 'RG 10/14/2012 11:28'!
isAdmin: aUser
	"Returns true if aUser is Admin"
	| instance |
	instance := AdminCollection default.
	^ instance hasObject: aUser ! !

!OperationValidator class methodsFor: 'as yet unclassified' stamp: 'RG 10/14/2012 14:05'!
modifyComment: aComment project: aProject user: aUser
	"Test if aUser can modify/remove a comment"
	( ( self isAdmin: aUser ) or: ( aProject isCoordinator: aUser ) ) ifTrue: [ ^true. ].
	^ ((aComment user) = aUser).! !

!OperationValidator class methodsFor: 'as yet unclassified' stamp: 'RG 10/13/2012 21:35'!
modifyProject: aProject user: aUser
	"A User can modify something from a project if is an admin or coodinator"
	| instance |
	instance := AdminCollection default.
	(( instance hasObject: aUser ) or: ( aProject isCoordinator: aUser )) ifTrue: [ ^true. ].
	^false.! !

Object subclass: #ProjectX
	instanceVariableNames: 'name type status description startDate endDate homepage coordinators tasks comments'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!ProjectX methodsFor: 'comparing' stamp: 'BBC 10/8/2012 16:12'!
= aProject
	"answers if two projects are the same"

	^ (self name = aProject name)! !

!ProjectX methodsFor: 'sets' stamp: 'BBC 10/14/2012 00:59'!
addComment: aComment
	"adds a comment to the project"
	
		[ comments add: aComment. ]
		on: Exception
		do: [:ex | ^false. ].
	      ^true! !

!ProjectX methodsFor: 'sets' stamp: 'BBC 10/13/2012 11:56'!
addCoordinator: aCoordinator
	"to add a coordinator to the Project"
	
	
	(self hasCoordinator: aCoordinator)
		ifTrue: [Transcript cr; show: 'Coordinator already added!!'] 
		ifFalse: [
			[ coordinators add: aCoordinator. ]
			on: Exception
			do: [:ex | ^false. ].
	            ^true.]
	
	
	! !

!ProjectX methodsFor: 'sets' stamp: 'MGH 10/17/2012 17:07'!
addTask: aTask
	"to add a task to the Project"
	
	
	(self hasTask: aTask)
		ifTrue: [Transcript cr; show: 'Task already added!!']
		ifFalse: [
			[ tasks add: aTask. 
			  aTask fromProject: self.]
			on: Exception
			do: [:ex | ^false. ].
			aTask fromProject: self.
	            ^true.].
	
	


! !

!ProjectX methodsFor: 'sets' stamp: 'BBC 10/15/2012 11:05'!
checkFinishedTasks
	"comment stating purpose of message"

	| tasksFinished |
	
	tasksFinished := true. 
	
	tasks do: [:task | (task status = 'Finished') ifFalse: [tasksFinished := false]].
	
	(tasksFinished = true) ifTrue: [self status: 'Finished']! !

!ProjectX methodsFor: 'gets' stamp: 'RG 10/14/2012 12:03'!
comments
	^comments.! !

!ProjectX methodsFor: 'gets' stamp: 'MGH 10/17/2012 17:16'!
coordinators
	"get project coordinators"

	^coordinators! !

!ProjectX methodsFor: 'gets' stamp: 'MGH 10/17/2012 17:16'!
coordinatorsStr
	"get project coordinators"

	coordinators do: [:coordinator | Transcript cr; show: (coordinator name) printString].! !

!ProjectX methodsFor: 'gets' stamp: 'BBC 10/8/2012 16:33'!
description
	"Answer the value of description"

	^ description! !

!ProjectX methodsFor: 'sets' stamp: 'BBC 10/8/2012 16:06'!
description: anObject
	"Set the value of description"

	description := anObject! !

!ProjectX methodsFor: 'gets' stamp: 'BBC 10/8/2012 16:33'!
endDate
	"Answer the value of endDate"

	^ endDate! !

!ProjectX methodsFor: 'sets' stamp: 'BBC 10/8/2012 16:34'!
endDate: aString
	"to set the value of endDate"
	
	endDate := aString asDate.! !

!ProjectX methodsFor: 'checking' stamp: 'BBC 10/13/2012 12:00'!
hasCoordinator: aCoordinator
	"Test if contains a coordinator"

	^(coordinators includes: aCoordinator) ! !

!ProjectX methodsFor: 'checking' stamp: 'BBC 10/13/2012 12:00'!
hasTask: aTask
	"Test if contains a Task"

	^(tasks includes: aTask) ! !

!ProjectX methodsFor: 'checking' stamp: 'BBC 10/15/2012 10:21'!
hasVolunteer: aVolunteer
	"Test if any task in the project contains a volunteer"
	
	| result |
	
	result := false.
	
	tasks do: [:task | (task hasVolunteer:aVolunteer) ifTrue: [result := true] ].
	
	^ result

	

! !

!ProjectX methodsFor: 'gets' stamp: 'BBC 10/15/2012 09:03'!
homepage
	"to get the project's homepage"

	^ homepage! !

!ProjectX methodsFor: 'sets' stamp: 'BBC 10/15/2012 09:04'!
homepage: anUrl
	"Set the project's homepage"

	homepage := anUrl! !

!ProjectX methodsFor: 'initialize-release' stamp: 'BBC 10/15/2012 11:35'!
initialize
	"project constructor"
	
	super initialize.
	self name: ''.
	self description:''.
	self type:''.
	self status: 'Open'.
	self startDate: Date today.
	tasks := OrderedCollection new.
	coordinators := OrderedCollection new.
	comments :=  OrderedCollection new.

	! !

!ProjectX methodsFor: 'test' stamp: 'RG 10/12/2012 23:52'!
isCoordinator: aUser
	"returns true or false depending if the user is a coordinator"
	^ coordinators includes: aUser.! !

!ProjectX methodsFor: 'sets' stamp: 'BBC 10/8/2012 16:06'!
name: anObject
	"Set the value of name"

	name := anObject! !

!ProjectX methodsFor: 'persistence' stamp: 'BBC 10/8/2012 16:29'!
remove
	"remove the project from the system"
	
	| instance |
	
	instance := ProjectCollection default.
	instance removeProject: self.
	Smalltalk snapshot: true andQuit: false.	 ! !

!ProjectX methodsFor: 'sets' stamp: 'MGH 10/15/2012 17:54'!
removeComment: aComment
	"to remove a coordinator from project"
	
	| index |
	index := comments indexOf: aComment ifAbsent: [ 0. ].
	( index > 0 ) ifTrue: [ comments removeAt: index. 
		                           ^true].
	^false
! !

!ProjectX methodsFor: 'sets' stamp: 'BBC 10/8/2012 16:27'!
removeCoordinator: aCoordinator
	"to remove a coordinator from project"
	
	| index |
	
	[index := (coordinators find: aCoordinator).
	(index isNil) ifFalse: [coordinators removeAt: index]. ]
	on: Exception
	do: [:ex | ^false. ].
	^true.
! !

!ProjectX methodsFor: 'sets' stamp: 'BBC 10/8/2012 16:47'!
removeTask: aTask
	"to remove a task from project"
	
	| index |
	
	[index := (tasks find: aTask).
	(index isNil) ifFalse: [tasks removeAt: index]. ]
	on: Exception
	do: [:ex | ^false. ].
	^true.
! !

!ProjectX methodsFor: 'persistence' stamp: 'BBC 10/13/2012 13:11'!
save
	"saves the project in the system"
	
	| projectInstance |
	
	projectInstance := ProjectCollection default.
	projectInstance addProject: self.
	"Smalltalk snapshot: true andQuit: false".	! !

!ProjectX methodsFor: 'sets' stamp: 'RG 10/12/2012 20:30'!
setCoordinator: aUser
	"set the user of the project"
	| instance coordinator |
	coordinator := Coordinator new.
	coordinator setFromUser: aUser.
	instance := CoordinatorCollection default.
	( instance hasObject: coordinator ) ifTrue: [ coordinator := instance getObject: coordinator. ]
										ifFalse: [ coordinator save. ].
	self addCoordinator: coordinator.

	! !

!ProjectX methodsFor: 'gets' stamp: 'BBC 10/8/2012 16:33'!
startDate
	"Answer the value of startDate"

	^ startDate! !

!ProjectX methodsFor: 'sets' stamp: 'BBC 10/8/2012 16:35'!
startDate: aString
	"to set the value of startDate"
	
	startDate := aString asDate.! !

!ProjectX methodsFor: 'gets' stamp: 'BBC 10/8/2012 16:06'!
status
	"Answer the value of status"

	^ status! !

!ProjectX methodsFor: 'sets' stamp: 'BBC 10/15/2012 10:59'!
status: aString
	"to set the value of status"
	
	status := aString.
	
	(status = 'Finished')
		ifTrue: [self endDate: (Date today)]! !

!ProjectX methodsFor: 'gets' stamp: 'MGH 10/17/2012 16:34'!
tasks
	"Answer the value of status"

	^ tasks! !

!ProjectX methodsFor: 'gets' stamp: 'BBC 10/8/2012 16:06'!
type
	"Answer the value of type"

	^ type! !

!ProjectX methodsFor: 'sets' stamp: 'BBC 10/8/2012 16:06'!
type: anObject
	"Set the value of type"

	type := anObject! !

!ProjectX methodsFor: 'persistence' stamp: 'BBC 10/8/2012 16:31'!
update
	"updates the information of the project from the system"
	
	| instance |
	
	instance := ProjectCollection default.
	instance updateProject: self.
	Smalltalk snapshot: true andQuit: false.	! !

Object subclass: #Skill
	instanceVariableNames: 'name description'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!Skill commentStamp: 'RG 9/19/2012 20:57' prior: 0!
Represent a skill of a volunteer or needed in a task.!

!Skill methodsFor: 'comparing' stamp: 'BBC 10/8/2012 14:47'!
= aSkill
	"Testing Equality"
	
	^ ((self name) = (aSkill name)).! !

!Skill methodsFor: 'gets' stamp: 'RG 9/19/2012 21:00'!
description
	"Getter of description"
	^description.! !

!Skill methodsFor: 'sets' stamp: 'RG 9/19/2012 21:01'!
description: aDescription
	"Setter of description"
	description := aDescription.! !

!Skill methodsFor: 'initialize-release' stamp: 'RG 9/19/2012 21:04'!
initialize
	"Empty constructor"
	super initialize.
	self name: ''.
	self description: ''.! !

!Skill methodsFor: 'initialize-release' stamp: 'RG 9/19/2012 21:06'!
initialize: aName desc: aDescription
	"Constructor with parameters"
	self name: aName.
	self description: aDescription.! !

!Skill methodsFor: 'gets' stamp: 'RG 9/19/2012 20:58'!
name
	"Getter of a name"
	^name.! !

!Skill methodsFor: 'sets' stamp: 'RG 9/19/2012 20:59'!
name: aName
	"Setter of name"
	name := aName.! !

!Skill methodsFor: 'persistence' stamp: 'RG 10/6/2012 16:22'!
remove
	"remove the skill from the system"
	| instance |
	instance := SkillCollection default.
	instance removeSkill: self.
	Smalltalk snapshot: true andQuit: false.	 ! !

!Skill methodsFor: 'persistence' stamp: 'BBC 10/13/2012 13:12'!
save
	"save the skill in the system"
	| skillInstance |
	skillInstance := SkillCollection default.
	skillInstance addSkill: self.
	"Smalltalk snapshot: true andQuit: false".	 ! !

!Skill methodsFor: 'persistence' stamp: 'RG 10/6/2012 16:22'!
update
	"updates the information of the skill from the system"
	| instance |
	instance := SkillCollection default.
	instance updateSkill: self.
	Smalltalk snapshot: true andQuit: false.	 ! !

Object subclass: #Task
	instanceVariableNames: 'name description status startDate endDate estimatedTime skills volunteers dependsOn dependents fromProject comments'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!Task commentStamp: 'BBC 10/2/2012 00:57' prior: 0!
stores a task!

!Task methodsFor: 'comparing' stamp: 'BBC 10/8/2012 14:48'!
= aTask
	"answers if two tasks are the same"

	^ (self name = aTask name)! !

!Task methodsFor: 'gets' stamp: 'MGH 10/21/2012 12:38'!
StrDependents
	"get task dependences"
      | temp |
      ((dependents size)==0) ifTrue: [^'No task depends on this']
	ifFalse: [
      temp := WriteStream on: String new.
	dependents do: [:task | temp nextPutAll: (((task name) asString) nextPutAll: ', ')].
	^temp]
! !

!Task methodsFor: 'gets' stamp: 'MGH 10/22/2012 13:31'!
StrDepends
	"get task dependences"
      | temp |
      ((dependsOn size)==0) ifTrue: [^'Not depend on any task']
	ifFalse: [
      temp := String new.
	dependsOn do: [:task | temp := ((task name) asString), ', '].
	^temp]
! !

!Task methodsFor: 'gets' stamp: 'MGH 10/22/2012 13:27'!
StrVolunteers
	"get task dependences"
      | temp |
      ((volunteers size)==0) ifTrue: [^'No volunteer assigned']
	ifFalse: [
      temp := String new.
	volunteers do: [:volun | temp :=temp, ((volun name) asString) , ', '].
	^temp].
! !

!Task methodsFor: 'sets' stamp: 'BBC 10/14/2012 00:45'!
addComment: aComment
	"adds a comment to the task"
	
		[ comments add: aComment. ]
		on: Exception
		do: [:ex | ^false. ].
	      ^true! !

!Task methodsFor: 'sets' stamp: 'BBC 10/13/2012 11:43'!
addSkill: aSkill
	"adds a skill to the task"
	
	(self hasSkill: aSkill)
		ifTrue: [Transcript cr; show: 'Skill already added!!'] 
		ifFalse: [
			[ skills add: aSkill. ]
			on: Exception
			do: [:ex | ^false. ].
	            ^true.]! !

!Task methodsFor: 'sets' stamp: 'BBC 10/13/2012 11:45'!
addVolunteer: aVolunteer
	"adds a volunteer to the task"
	
	
	(self hasVolunteer: aVolunteer)
		ifTrue: [Transcript cr; show: 'Volunteer already added!!'] 
		ifFalse: [
			[ volunteers add: aVolunteer. ]
			on: Exception
			do: [:ex | ^false. ].
	            ^true.]
	
	
! !

!Task methodsFor: 'checking' stamp: 'BBC 10/13/2012 18:48'!
checkDependences

	| allFinished | 
	
	allFinished := true.
	
	dependsOn do: [:task | ((task status) = 'Open') ifTrue: [allFinished:=false] ].
	
	(allFinished)
		ifTrue: [self status: 'Open']! !

!Task methodsFor: 'gets' stamp: 'BBC 10/14/2012 00:44'!
comments
	"get task comments"

	comments do: [:comment | Transcript cr; show: (comment message) printString].
! !

!Task methodsFor: 'gets' stamp: 'BBC 10/13/2012 19:02'!
dependents
	"get task dependences"

	dependents do: [:task | Transcript cr; show: (task name) printString].
! !

!Task methodsFor: 'sets' stamp: 'BBC 10/13/2012 19:01'!
dependents: aTask
	"to set task dependences"
	
	
	dependents add: aTask.
	
! !

!Task methodsFor: 'gets' stamp: 'BBC 10/3/2012 23:13'!
dependsOn
	"get task dependences"

	dependsOn do: [:task | Transcript cr; show: (task name) printString].
! !

!Task methodsFor: 'sets' stamp: 'BBC 10/13/2012 19:12'!
dependsOn: aTask
	"to set task dependences"
	
	
	dependsOn add: aTask.
	dependsOn do: [:task | ((task status) = 'Open') ifTrue: [self status: 'Frozen'] ].
	
	aTask dependents: self.
	
! !

!Task methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:29'!
description
	"get task description"

	^ description! !

!Task methodsFor: 'sets' stamp: 'BBC 10/5/2012 19:56'!
description: aString
	"to set the value of description"
	
	description := aString.! !

!Task methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:29'!
endDate
	"get task end date"

	^ endDate! !

!Task methodsFor: 'sets' stamp: 'BBC 10/5/2012 19:56'!
endDate: aString
	"to set the value of endDate"
	
	endDate := aString asDate.! !

!Task methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:30'!
estimatedTime
	"get task estimated time"

	^ estimatedTime! !

!Task methodsFor: 'sets' stamp: 'BBC 10/5/2012 19:56'!
estimatedTime: anInteger
	"to set the value of estimatedTime, in hours"
	
	estimatedTime := anInteger.! !

!Task methodsFor: 'gets' stamp: 'BBC 10/13/2012 18:11'!
fromProject
	"get task project"

	^ fromProject! !

!Task methodsFor: 'sets' stamp: 'BBC 10/13/2012 18:12'!
fromProject: aProject
	"to set the project that has this task"
	
	fromProject := aProject.! !

!Task methodsFor: 'as yet unclassified' stamp: 'RG 10/6/2012 15:02'!
getListOfVolunteers: aListOfVolunteers
	"Sort the list of volunteers by the number of similarities of skills with the task"
	| list temp |
	list := OrderedCollection new.
	aListOfVolunteers do: [ :each | list add: (Association key: each value: (each numberOfSimilarities: skills) ). ].
	temp := list sort: [ :v1 :v2 | (v1 value) >= (v2 value). ].
	^temp collect: [ :each | each key. ].! !

!Task methodsFor: 'checking' stamp: 'BBC 10/13/2012 11:59'!
hasSkill: aSkill
	"Test if contains a skill"

	^(skills includes: aSkill)
	 
! !

!Task methodsFor: 'checking' stamp: 'MGH 10/14/2012 21:01'!
hasSomeSkill: aSkills
      "Test if contains some skill of aSkills"
      |i size|
      size := aSkills size.
      i := 1.
      [ i <= size ] whileTrue: 
        [ (self hasSkill: (aSkills at: i)) ifTrue: [^true].
          i:= i+1.].
      ^false! !

!Task methodsFor: 'checking' stamp: 'BBC 10/13/2012 12:00'!
hasVolunteer: aVolunteer
	"Test if contains a Volunteer"

	^(volunteers includes: aVolunteer) 

	 
! !

!Task methodsFor: 'initialize-release' stamp: 'BBC 10/14/2012 00:43'!
initialize
	"task constructor"
	
	super initialize.
	self name: ''.
	self description: ''.
	self status: 'Open'.
	self startDate: Date today.
	self estimatedTime: ''.
	dependsOn := OrderedCollection new.
	dependents := OrderedCollection new.
	skills := OrderedCollection new.
	volunteers := OrderedCollection new.
	comments := OrderedCollection new.
	! !

!Task methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:30'!
name
	"get task name"

	^ name! !

!Task methodsFor: 'sets' stamp: 'BBC 10/5/2012 19:56'!
name: aString
	"to set the value of name"
	
	name := aString.! !

!Task methodsFor: 'persistence' stamp: 'BBC 10/8/2012 14:59'!
remove
	"remove the task from the system"
	
	| instance |
	
	instance := TaskCollection default.
	instance removeTask: self.
	Smalltalk snapshot: true andQuit: false.	 ! !

!Task methodsFor: 'sets' stamp: 'BBC 10/14/2012 00:51'!
removeComment: aComment
	"to remove a comment from task"
	
	| index |
	
	[index := (comments find: aComment).
	(index isNil) ifFalse: [comments removeAt: index]. ]
	on: Exception
	do: [:ex | ^false. ].
	^true.
	! !

!Task methodsFor: 'sets' stamp: 'BBC 10/8/2012 16:23'!
removeSkill: aSkill
	"to remove a skill from task"
	
	| index |
	
	[index := (skills find: aSkill).
	(index isNil) ifFalse: [skills removeAt: index]. ]
	on: Exception
	do: [:ex | ^false. ].
	^true.
	! !

!Task methodsFor: 'sets' stamp: 'BBC 10/13/2012 17:55'!
removeVolunteer: aVolunteer
	"to remove a volunteer from task"
	
	| index |
	
	[index := (volunteers find: aVolunteer).
	(index isNil) ifFalse: [volunteers removeAt: index]. ]
	on: Exception
	do: [:ex  | ^false. ].
	^true.
	! !

!Task methodsFor: 'persistence' stamp: 'BBC 10/13/2012 13:11'!
save
	"saves a task in the system"
	
	| taskInstance|
	
	taskInstance := TaskCollection default.
	taskInstance addTask: self.
	"Smalltalk snapshot: true andQuit: false".	

! !

!Task methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:30'!
skills
	"get task skills"

	skills do: [:skill | Transcript cr; show: (skill name) printString].
! !

!Task methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:30'!
startDate
	"get task start date"

	^ startDate! !

!Task methodsFor: 'sets' stamp: 'BBC 10/8/2012 16:34'!
startDate: aString
	"to set the value of startDate"
	
	startDate := aString asDate.! !

!Task methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:30'!
status
	"get task status"

	^ status! !

!Task methodsFor: 'sets' stamp: 'BBC 10/15/2012 11:29'!
status: aString
	"to set the value of status"
	
	| p1 |
	
	status := aString.
	
	(status = 'Finished')
		ifTrue: [dependents do: [:task | (task checkDependences) ]. self endDate: (Date today)].
		
	p1 := self fromProject. 
	
	(p1 = nil)
		ifFalse: [p1 checkFinishedTasks].

	
! !

!Task methodsFor: 'persistence' stamp: 'BBC 10/8/2012 15:00'!
update
	"updates the information of the task from the system"
	
	| instance |
	
	instance := TaskCollection default.
	instance updateTask: self.
	Smalltalk snapshot: true andQuit: false.	 ! !

!Task methodsFor: 'gets' stamp: 'MGH 10/17/2012 17:38'!
volunteers
	"get task volunteers"

	^volunteers
! !

!Task methodsFor: 'gets' stamp: 'MGH 10/21/2012 12:36'!
volunteersStr
	"get task volunteers"
      ((volunteers size)==0) ifTrue: [Transcript cr; show: 'No volunteer assigned' printString]
	ifFalse: [volunteers do: [:volunteer | Transcript cr; show: (volunteer name) printString]].
! !

Object subclass: #User
	instanceVariableNames: 'login password name email photo inbox'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!User commentStamp: 'shout 10/2/2012 18:25' prior: 0!
User of the system!

User subclass: #Admin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!Admin commentStamp: 'shout 10/2/2012 18:33' prior: 0!
Admin of the system!

!Admin methodsFor: 'as yet unclassified' stamp: 'RG 10/14/2012 00:11'!
= anAdmin
	"comment stating purpose of message"
	^(anAdmin name = name).! !

!Admin methodsFor: 'as yet unclassified' stamp: 'RG 10/14/2012 00:13'!
save
	"save the admin in the system"
	| instance |
	instance := AdminCollection default.
	(instance hasObject: self) ifFalse: [ instance addAdmin: self. ].
	Smalltalk snapshot: true andQuit: false.	 ! !

!Admin methodsFor: 'as yet unclassified' stamp: 'RG 10/14/2012 00:08'!
setFromUser: aUser
	self name: (aUser name).
	self login: (aUser login).
	self password: (aUser password).
	self email: (aUser email).
	self inbox: (aUser inbox).! !

User subclass: #Coordinator
	instanceVariableNames: 'organization coordinatedProjects'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!Coordinator commentStamp: 'BBC 9/22/2012 19:14' prior: 0!
stores a coordinator!

!Coordinator methodsFor: 'comparing' stamp: 'BBC 10/8/2012 15:13'!
= aCoordinator
	"answers if two coordinators are the same"

	^ (self name = aCoordinator name)! !

!Coordinator methodsFor: 'operation' stamp: 'MGH 10/15/2012 10:46'!
ChangeState: aTask status: aStatus
	"Send a offer to some user"

	aTask status: aStatus.! !

!Coordinator methodsFor: 'operation' stamp: 'MGH 10/14/2012 23:40'!
ReviseOffer: aOffer message: aMessage accepted: aAccepted
	"Send a offer to some user"
	|coordinators size i coordinator task|
	task := aOffer task.
	aOffer receiver: self.
	coordinators := (task fromProject) coordinators.
	self responseOffer: aMessage offer: aOffer accepted: aAccepted.
	size := coordinators size.
      i := 1.
      [ i <= size ] whileTrue: 
        [ coordinator:=coordinators at: i.
          coordinator removeOffer: aOffer.
          i:=i+1.].
      aAccepted ifTrue: [task addVolunteer: (aOffer sender)].! !

!Coordinator methodsFor: 'operation' stamp: 'MGH 10/14/2012 23:51'!
SendOffer: aTask message: aMessage volunteer: aVolunteer
	"Send a offer to some user"
	|offer|
	offer := Offer new.
	offer SendOffer: self receiver: aVolunteer message: aMessage task: aTask.! !

!Coordinator methodsFor: 'sets' stamp: 'BBC 10/13/2012 11:51'!
addCoordinatedProject: aProject
	"to add a project in coordinatedProjects"
	
	
	(self hasCoordinatedProject: aProject)
		ifTrue: [Transcript cr; show: 'Project already added!!'] 
		ifFalse: [
			[ coordinatedProjects add: aProject. ]
			on: Exception
			do: [:ex | ^false. ].
	            ^true.]
	

! !

!Coordinator methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:32'!
coordinatedProjects
	"get coordinator coordinated projects"

	coordinatedProjects do: [:project | Transcript cr; show: (project name) printString].! !

!Coordinator methodsFor: 'checking' stamp: 'BBC 10/13/2012 12:00'!
hasCoordinatedProject: aProject
	"Test if contains a coordinated project"

	^(coordinatedProjects includes: aProject) ! !

!Coordinator methodsFor: 'initialize-release' stamp: 'BBC 10/8/2012 15:44'!
initialize
	"coordinator constructor"
	
	super initialize.
	self name: ''.
	self organization:''.
	coordinatedProjects := OrderedCollection new.

	
! !

!Coordinator methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:32'!
organization
	"get coordinator organization"

	^ organization! !

!Coordinator methodsFor: 'sets' stamp: 'BBC 10/8/2012 15:07'!
organization: aString
	"coordinator's organization"
	
	organization := aString.! !

!Coordinator methodsFor: 'persistence' stamp: 'BBC 10/8/2012 15:39'!
remove
	"remove the coordinator from the system"
	
	| instance |
	
	instance := CoordinatorCollection default.
	instance removeCoordinator: self.
	Smalltalk snapshot: true andQuit: false.	 ! !

!Coordinator methodsFor: 'sets' stamp: 'BBC 10/8/2012 16:23'!
removeCoordinatedProject: aProject
	"to remove a project from coordinatedProjects"
	
	| index |
	
	[index := (coordinatedProjects find: aProject).
	(index isNil) ifFalse: [coordinatedProjects removeAt: index]. ]
	on: Exception
	do: [:ex | ^false. ].
	^true.
	


! !

!Coordinator methodsFor: 'persistence' stamp: 'RG 10/12/2012 20:00'!
save
	"save the coordinator in the system"
	| coordinatorInstance |
	coordinatorInstance := CoordinatorCollection default.
	(coordinatorInstance hasObject: self) ifFalse: [ coordinatorInstance addCoordinator: self. ].
	Smalltalk snapshot: true andQuit: false.	 ! !

!Coordinator methodsFor: 'create/remove/edit' stamp: 'RG 10/12/2012 20:03'!
setFromUser: aUser
	self name: (aUser name).
	self login: (aUser login).
	self password: (aUser password).
	self email: (aUser email).
	self inbox: (aUser inbox).! !

!Coordinator methodsFor: 'persistence' stamp: 'BBC 10/8/2012 15:40'!
update
	"updates the information of the coordinator from the system"
	
	| instance |
	
	instance := CoordinatorCollection default.
	instance updateCoordinator: self.
	Smalltalk snapshot: true andQuit: false.	 ! !

!User methodsFor: 'comparing' stamp: 'RG 10/14/2012 14:03'!
= aUser
	^ (name = aUser name).! !

!User methodsFor: 'operation' stamp: 'MGH 10/8/2012 16:10'!
addOffer: message offer: aOffer
	"Add an offer into the inbox"
	[ inbox add: aOffer.]
	on: Exception
	do: [:ex | ^false. ].
	^true.! !

!User methodsFor: 'gets' stamp: 'shout 10/7/2012 22:53'!
email
	"get user email"

	^ email! !

!User methodsFor: 'sets' stamp: 'RG 10/8/2012 14:21'!
email: aEmail
	"set email"
	email := aEmail.! !

!User methodsFor: 'gets' stamp: 'RG 10/12/2012 20:03'!
inbox
	^inbox.! !

!User methodsFor: 'sets' stamp: 'MGH 10/15/2012 00:28'!
inbox: aInbox
	"sets inbox"
	inbox := aInbox! !

!User methodsFor: 'initialize-release' stamp: 'RG 10/12/2012 17:55'!
initialize
	"Empty constructor"
	login := ''.
	password := ''.
	email := ''.
	name := ''.
	inbox := OrderedCollection new.! !

!User methodsFor: 'gets' stamp: 'RG 10/8/2012 14:23'!
login
	^login.! !

!User methodsFor: 'sets' stamp: 'RG 10/8/2012 14:23'!
login: aLogin
	"sets login"
	login := aLogin! !

!User methodsFor: 'gets' stamp: 'shout 10/7/2012 22:50'!
name
	^name.! !

!User methodsFor: 'sets' stamp: 'shout 10/7/2012 22:50'!
name: aName
	"comment stating purpose of message"
	name := aName.! !

!User methodsFor: 'gets' stamp: 'RG 10/8/2012 14:25'!
password
	^password! !

!User methodsFor: 'sets' stamp: 'RG 10/8/2012 14:26'!
password: aPassword
	"sets password"
	password := aPassword.! !

!User methodsFor: 'as yet unclassified' stamp: 'MGH 10/14/2012 23:11'!
removeOffer: aOffer
	"Response an offer"
	| index |
	[index := (inbox find: aOffer).
	(index isNil) ifFalse: [inbox removeAt: index]. ]
	on: Exception
	do: [:ex | ^false. ].
	^true.! !

!User methodsFor: 'operation' stamp: 'MGH 10/14/2012 23:11'!
responseOffer: message offer: aOffer accepted: aAccepted
	"Response an offer"
	| index |
	aOffer ResponseOffer: aAccepted message: message. 
	[index := (inbox find: aOffer).
	(index isNil) ifFalse: [inbox removeAt: index]. ]
	on: Exception
	do: [:ex | ^false. ].
	^true.! !

!User methodsFor: 'gets' stamp: 'RG 10/12/2012 22:21'!
setFromUser: aUser
	"comment stating purpose of message"
	self login: (aUser login). 
	self password: (aUser password).
	self name: (aUser name). 
	self email: (aUser email).
	self inbox: (aUser inbox).! !

User subclass: #Volunteer
	instanceVariableNames: 'skills disponibility availability workTime finishedTasks finishedProjects birthday'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!Volunteer commentStamp: 'RG 9/19/2012 21:15' prior: 0!
Represents a volunteer.!

!Volunteer methodsFor: 'comparing' stamp: 'BBC 10/8/2012 15:14'!
= aVolunteer
	"Comparing volunteers"
	
	^(self name = aVolunteer name)! !

!Volunteer methodsFor: 'operation' stamp: 'MGH 10/15/2012 00:18'!
SendOffer: aTask message: aMessage
	"Create an volunteer account"
	|offer offers|
	offer := Offer new.
	offers:= OfferCollection default.
	(offers hasOffer: offer) ifFalse: [offer SendOffer: self task: aTask message: aMessage].! !

!Volunteer methodsFor: 'operation' stamp: 'BBC 10/13/2012 12:02'!
addSkill: aSkill
	"Add a skill to the volunteer"
	
		
	(self hasSkill: aSkill)
		ifTrue: [Transcript cr; show: 'Skill already added!!'] 
		ifFalse: [
			[ skills add: aSkill. ]
			on: Exception
			do: [:ex | ^false. ].
	            ^true.]
	! !

!Volunteer methodsFor: 'gets' stamp: 'RG 9/19/2012 21:41'!
availability
	"Getter availability"
	^availability.! !

!Volunteer methodsFor: 'sets' stamp: 'RG 9/19/2012 21:43'!
availability: anAvailability
	"Setter of availability"
	availability := anAvailability.! !

!Volunteer methodsFor: 'gets' stamp: 'RG 9/19/2012 21:37'!
birthday
	"Getter of birthday"
	^birthday.! !

!Volunteer methodsFor: 'sets' stamp: 'RG 9/19/2012 21:38'!
birthday: aBirthday
	"Setter of Birthday"
	birthday := aBirthday.! !

!Volunteer methodsFor: 'operation' stamp: 'MGH 10/17/2012 17:00'!
createAccount: aLogin pass: aPwd name: aName email: aEmail photo: aPhoto birthday: aBirthDay
	"Create an volunteer account"
	login := aLogin.
	password := aPwd.
	name := aName.
	email := aEmail.
	photo := aPhoto.
	skills := OrderedCollection new.
	disponibility := True.
	availability := True.
	workTime := 0.
	finishedTasks := 0.
	finishedProjects := 0.
	birthday := aBirthDay.
	inbox := OrderedCollection new.! !

!Volunteer methodsFor: 'gets' stamp: 'RG 9/19/2012 21:39'!
disponibility
	"Getter of disponibility"
	^disponibility.! !

!Volunteer methodsFor: 'sets' stamp: 'RG 9/19/2012 21:41'!
disponibility: aDisponibility
	"Setter of disponibility"
	disponibility := aDisponibility.! !

!Volunteer methodsFor: 'gets' stamp: 'RG 9/19/2012 21:46'!
finishedProjects
	"Getter finishedProjects"
	^finishedProjects.! !

!Volunteer methodsFor: 'sets' stamp: 'RG 9/19/2012 21:47'!
finishedProjects: numberFinished
	"Setter finishedPrijects"
	finishedProjects := numberFinished.! !

!Volunteer methodsFor: 'gets' stamp: 'RG 9/19/2012 21:49'!
finishedTasks
	"Getter finishedTasks"
.	^finishedTasks.! !

!Volunteer methodsFor: 'sets' stamp: 'RG 9/19/2012 21:49'!
finishedTasks: numberFinished
	"Setter finished Tasks"
	finishedTasks := numberFinished.! !

!Volunteer methodsFor: 'checking' stamp: 'RG 10/1/2012 16:06'!
hasSkill: aSkill
	"Test if has an specific skill"
	^ (skills includes: aSkill).! !

!Volunteer methodsFor: 'initialize-release' stamp: 'RG 10/1/2012 14:13'!
initialize
	"Constructor"
	skills := OrderedCollection new.
	disponibility := ''.
	availability := false.
	workTime := ''.
	finishedTasks := 0.
	finishedProjects := 0.
	birthday := Date new.
	name := ''.! !

!Volunteer methodsFor: 'operation' stamp: 'RG 10/1/2012 16:05'!
numberOfSimilarities: aListOfSkills
	"Given a list of skills, gets the quantity of those that the volunteer posses"
	| count |
	count := 0.
	aListOfSkills do: [ :aSkill |
		( self hasSkill: aSkill ) ifTrue: [ count := count + 1. ].
	].
	^count.! !

!Volunteer methodsFor: 'persistence' stamp: 'RG 10/6/2012 16:16'!
remove
	"remove the volunteer from the system"
	| instance |
	instance := VolunteerCollection default.
	instance removeVolunteer: self.
	Smalltalk snapshot: true andQuit: false.! !

!Volunteer methodsFor: 'operation' stamp: 'RG 10/8/2012 16:04'!
removeSkill: aSkill
	"remove a skill from the skills of the volunteer"
	"Returns true or false depending on the outcome of the operation"
	| index |
	[ index := (skills find: aSkill).
	  skills removeAt: index.]
	on: Exception
	do: [:ex | ^false. ].
	^true.! !

!Volunteer methodsFor: 'persistence' stamp: 'BBC 10/13/2012 13:12'!
save
	"save the volunteer in the system"
	
	| volunteerInstance |
	
	volunteerInstance := VolunteerCollection default.
	volunteerInstance addVolunteer: self.
	"Smalltalk snapshot: true andQuit: false."	 ! !

!Volunteer methodsFor: 'gets' stamp: 'RG 10/6/2012 15:53'!
skills
	"Return the list of skills"
	^skills! !

!Volunteer methodsFor: 'checking' stamp: 'MGH 10/14/2012 21:03'!
suggestions
       |tasks size i suggetedSkills task|
       tasks := TaskCollection default.
       size := tasks collection size.
       suggetedSkills := OrderedCollection new.
       i := 1.
       [ i <= size ] whileTrue: 
        [ task:=tasks collection at: i.
	    i:=i+1.
          (task hasSomeSkill: skills) ifTrue: [suggetedSkills add: task]].
       ^suggetedSkills
! !

!Volunteer methodsFor: 'persistence' stamp: 'RG 10/6/2012 16:19'!
update
	"update the information of the volunteer from the system"
	| instance |
	instance := VolunteerCollection default.
	instance updateVolunteer: self.
	Smalltalk snapshot: true andQuit: false.! !

!Volunteer methodsFor: 'gets' stamp: 'RG 9/19/2012 21:44'!
workTime
	"Getter of worktime"
	^workTime.! !

!Volunteer methodsFor: 'sets' stamp: 'RG 9/19/2012 21:45'!
workTime: aWorkTime
	"comment stating purpose of message"
	workTime := aWorkTime.! !
